/**
 * Custom javascript
 *
 */
(function ($) {

  var pagingIsEnabled = true;
  var currentID = '';

  /**
   * Automatic table of contents
   * https://css-tricks.com/automatic-table-of-contents/
   *
   */
  Drupal.behaviors.tableOfContents = {
    attach: function (context, settings) {
      if ($(".multipage").length > 0) {
        var ToC =
          "<nav role='navigation' id='navigation--in-page' class='navigation navigation--in-page'>" +
          "<h5>Table of contents</h5>" +
          "<ol class='list-unstyled'>";

        var newLine, el, title, link;
        var index = 0;

        $(".multipage h2").each(function () {

          el = $(this);
          title = el.text();
          link = "#" + el.attr("id");

          if (index == 0) {
            setCurrentID(el.attr("id"));
          }

          newLine =
            "<li" + ((index == 0) ? ' class="active" ' : '' ) + ">" +
            "<a href='" + link + "' data-rel=" + el.attr("id") + ">" +
            title +
            "</a>" +
            "</li>";

          ToC += newLine;
          index++;
        });

        ToC +=
          "</ol>" +
          "</nav>";

        $(".cover__navigation").prepend(ToC);

        // Check if paging is enabled and handle show / hide if so ..
        $(".cover__navigation .navigation a").click(function () {
          var targetID = $(this).attr('href').toString().replace('#', '');
          setCurrentID(targetID);
          if (pagingIsEnabled) {
            $('.multipage__section').hide().prev().hide();
            $('#' + targetID).show().next().show();
          }
        });
      }
    }
  };

  /**
   * A pager for the multipage document
   *
   */
  Drupal.behaviors.multipagePager = {
    attach: function (context, settings) {
      if ($(".multipage").length > 0) {

        // Unhide pager controls
        $("ul.pagination").removeClass('hidden');

        $(".multipage__section").each(function (e) {
          if (e != 0) {
            $(this).hide().prev().hide();
            $(this).prev().hide();
          }
        });

        $("#next").click(function () {

          $("html, body").animate({scrollTop: $("#content").offset().top}, "fast");

          var nextTitle = null;
          var nextText = null;

          if ($(".multipage h2:visible").next().next().length != 0) {
            nextTitle = $(".multipage h2:visible").next().next();
            nextText = nextTitle.next();
            $(".multipage h2:visible").next().hide().prev().hide();
            nextTitle.show();
            nextText.show();

          }
          else {
            $(".multipage h2:visible").hide();
            $(".multipage__section:visible").hide();
            nextText = $(".multipage__section:first");
            nextTitle = $(".multipage h2:first");
            nextText.show();
            nextTitle.show();
          }
          setCurrentID(nextTitle.attr('id'));
          return false;
        });

        $("#previous").click(function () {

          $("html, body").animate({scrollTop: $("#content").offset().top}, "fast");

          var previousTitle = null;
          var previousText = null;
          if ($(".multipage h2:visible").prev().prev().length != 0) {
            previousTitle = $(".multipage h2:visible").prev().prev();
            previousText = previousTitle.next();
            $(".multipage h2:visible").next().hide().prev().hide();
            previousTitle.show();
            previousText.show();
          }
          else {
            $(".multipage h2:visible").hide();
            $(".multipage__section:visible").hide();
            previousText = $(".multipage__section:last");
            previousTitle = $(".multipage h2:last");
            previousText.show();
            previousTitle.show();
          }
          setCurrentID(previousTitle.attr('id'));
          return false;
        });
      }
    }
  };

  /**
   * If the page is called with an anchor parameter on pageLoad ..
   */
  Drupal.behaviors.jumpToAnchorOnPageLoad = {
    attach: function (context, settings) {
      if ($(".multipage").length > 0) {
        var targetID = window.location.hash.substring(1);
        // sanitation against XSS
        targetID = targetID.replace(/[^a-zA-Z0-9_-]/g, '');
        if (targetID) {
          if ($('#' + targetID).length > 0) {
            setCurrentID(targetID);
            $('#' + targetID).show().next().show();
            if (!$('#' + targetID).is(".multipage h2:first")) {
              $(".multipage h2:first").hide();
              $(".multipage__section:first").hide();
            }
          }
        }
      }
    }
  };

  /**
   * Anchor links to sections of the multipage that aren't currently active
   * don't work. This makes sure that if an anchor link on the current page is
   * clicked, it becomes the active section.
   */
  Drupal.behaviors.anchorClick = {
    attach: function (context, settings) {
      if ($(".multipage").length > 0) {
        $('a').click(function(evt) {
          // Gets the anchor.
          var hash = $(this).prop('hash');
          // Checks that the a element clicked has an anchor.
          if(hash && hash.slice(0,1) == '#') {
            var href = $(this).attr('href').toString();
            // Gets the anchor link.
            var targetID = href.substring(href.indexOf("#") + 1);
            // sanitation against XSS.
            targetID = targetID.replace(/[^a-zA-Z0-9_-]/g, '');
            // Hides the old section, shows the new section.
            setCurrentID(targetID);
            $('#' + targetID).show().next().show();
            $(this).parent().parent('.multipage__section').hide().prev().hide();
          }
        });
      }
    }
  };

  /**
   * Toggles if the multipage should be displayed collapsed or expanded
   */
  Drupal.behaviors.togglePaging = {
    attach: function (context, settings) {
      if ($(".multipage").length > 0) {
        $('.js-multipage-disable-paging').removeClass('hidden');

        // Disable paging
        $('.js-multipage-disable-paging').click(function (e) {
          pagingIsEnabled = false;
          $('ul.pagination').addClass('hidden');
          $('.multipage__section').show();
          $('.js-multipage-enable-paging').removeClass('hidden');
          $('.js-multipage-disable-paging').addClass('hidden');
          return false;
        });

        // Enable paging
        $('.js-multipage-enable-paging').click(function (e) {
          pagingIsEnabled = true;
          $('ul.pagination').removeClass('hidden');
          $('.multipage__section').hide();
          $('#' + currentID).parent().parent('.multipage__section').show();
          $('#' + currentID).next().show();
          $('.js-multipage-enable-paging').addClass('hidden');
          $('.js-multipage-disable-paging').removeClass('hidden');
          return false;
        });
      }
    }
  };

  /**
   * Add classes to the body when user scolls down
   *
   */
  Drupal.behaviors.MultipageScrollHelpers = {
    attach: function (context, settings) {
      $(window).scroll(function () {
        if ($(this).scrollTop() > 800) {
          $('body').addClass("you-are-going-down-on-a-multipage");
        }
        else {
          $('body').removeClass("you-are-going-down-on-a-multipage");
        }

        if ($(window).scrollTop() + $(window).height() > $(document).height() - 700) {
          $('body').addClass("you-are-near-the-bottom-on-a-multipage");
        }
        else {
          $('body').removeClass("you-are-near-the-bottom-on-a-multipage");
        }
      });
    }
  };

  /**
   * Sets the current ID and highlights the anchor link in the ToC
   * @param {Object} id
   */
  function setCurrentID(id) {
    $(".cover__navigation .navigation li").removeClass('active');
    $(".cover__navigation .navigation a[data-rel=\"" + id + "\"]").parent().addClass('active');
    currentID = id;
  }

})(jQuery);
